[−][src]Function pspsdk_sys::sdk::_sceKernelExitThread
pub unsafe extern "C" fn _sceKernelExitThread()
Exit the thread (probably used as the syscall when the main thread returns
pub unsafe extern "C" fn _sceKernelExitThread()
Exit the thread (probably used as the syscall when the main thread returns