[][src]Function pspsdk_sys::sdk::pspDebugGetStackTrace2

pub unsafe extern "C" fn pspDebugGetStackTrace2(
    regs: *mut PspDebugRegBlock,
    trace: *mut PspDebugStackTrace,
    max: c_int
) -> c_int

Do a stack trace from the current exception. @note This function really isn't too general purpose and it is more than likely to generate a few false positives but I consider that better then missing out calls entirely. You have to use your discretion, your code and a objdump to work out if some calls are completely surprious or not ;)

@param regs - Pointer to a register block from an exception. @param trace - Pointer to an array of PspDebugStackTrace structures. @param max - The maximum number of traces to make.

@return The number of functions found.