[−][src]Function pspsdk_sys::sdk::pspDebugKbDrawString
pub unsafe extern "C" fn pspDebugKbDrawString(str: *mut c_char)
Draw the string at the top of the box
@param str - The string to print
pub unsafe extern "C" fn pspDebugKbDrawString(str: *mut c_char)
Draw the string at the top of the box
@param str - The string to print