[−][src]Function pspsdk_sys::sdk::pspDebugScreenClearLineDisable
pub unsafe extern "C" fn pspDebugScreenClearLineDisable()
Disable the clear line function that causes flicker on constant refreshes
pub unsafe extern "C" fn pspDebugScreenClearLineDisable()
Disable the clear line function that causes flicker on constant refreshes