[][src]Function pspsdk_sys::sdk::pspDebugScreenKprintf

pub unsafe extern "C" fn pspDebugScreenKprintf(format: *const c_char, ...)

Do a printf to the debug screen. @note This is for kernel mode only as it uses a kernel function to perform the printf instead of using vsnprintf, use normal printf for user mode.

@param format - Format string to print @param ... - Arguments