[−][src]Function pspsdk_sys::sdk::pspDebugScreenSetBase
pub unsafe extern "C" fn pspDebugScreenSetBase(base: *mut u32)
Set the video ram base used for the screen
@param base - Base address in bytes
pub unsafe extern "C" fn pspDebugScreenSetBase(base: *mut u32)
Set the video ram base used for the screen
@param base - Base address in bytes