[−][src]Function pspsdk_sys::sdk::pspDebugScreenSetOffset
pub unsafe extern "C" fn pspDebugScreenSetOffset(offset: c_int)
Set the video ram offset used for the screen
@param offset - Offset in bytes
pub unsafe extern "C" fn pspDebugScreenSetOffset(offset: c_int)
Set the video ram offset used for the screen
@param offset - Offset in bytes