[−][src]Function pspsdk_sys::sdk::pspDebugSioInit
pub unsafe extern "C" fn pspDebugSioInit()
Initialise the remote SIO port (defaults to 4800 8N1). @note will delay 2 seconds to wait for the power to come up.
pub unsafe extern "C" fn pspDebugSioInit()
Initialise the remote SIO port (defaults to 4800 8N1). @note will delay 2 seconds to wait for the power to come up.