pspSdkLoadStartModuleWithArgs

Function pspSdkLoadStartModuleWithArgs 

pub unsafe extern "C" fn pspSdkLoadStartModuleWithArgs(
    filename: *const c_char,
    mpid: c_int,
    argc: c_int,
    argv: *const *const c_char,
) -> SceUID
Load a module and start it with arguments

@param filename - Path to the module. @param mpid - Memory parition ID to use to load the module int. @param argc - Number of arguments to pass to start module @param argv - Array of arguments

@return - The UID of the module on success, otherwise one of ::PspKernelErrorCodes.