[−][src]Function pspsdk_sys::sdk::sceGuInit
pub unsafe extern "C" fn sceGuInit()
Initalize the GU system
This function MUST be called as the first function, otherwise state is undetermined.
pub unsafe extern "C" fn sceGuInit()
Initalize the GU system
This function MUST be called as the first function, otherwise state is undetermined.