sceHttpReadData

Function sceHttpReadData 

pub unsafe extern "C" fn sceHttpReadData(
    requestid: c_int,
    data: *mut c_void,
    datasize: c_uint,
) -> c_int
Read a http request response.

@param requestid - ID of the request created by sceHttpCreateRequest or sceHttpCreateRequestWithURL @param data - Buffer for the response data to be stored @param datasize - Size of the buffer @return The size read into the data buffer, 0 if there is no more data, < 0 on error.