[−][src]Function pspsdk_sys::sdk::sceKernelBootFrom
pub unsafe extern "C" fn sceKernelBootFrom() -> c_int
Gets the device in which the application was launched.
@return the device code, one of PSPBootFrom values.
pub unsafe extern "C" fn sceKernelBootFrom() -> c_int
Gets the device in which the application was launched.
@return the device code, one of PSPBootFrom values.