[][src]Function pspsdk_sys::sdk::sceKernelCreateCallback

pub unsafe extern "C" fn sceKernelCreateCallback(
    name: *const c_char,
    func: SceKernelCallbackFunction,
    arg: *mut c_void
) -> c_int

Create callback

@par Example: @code int cbid; cbid = sceKernelCreateCallback("Exit Callback", exit_cb, NULL); @endcode

@param name - A textual name for the callback @param func - A pointer to a function that will be called as the callback @param arg - Argument for the callback ?

@return >= 0 A callback id which can be used in subsequent functions, < 0 an error.