pub unsafe extern "C" fn sceKernelDelaySysClockThread(
delay: *mut SceKernelSysClock,
) -> c_intExpand description
Delay the current thread by a specified number of sysclocks
@param delay - Delay in sysclocks
@return 0 on success, < 0 on error
pub unsafe extern "C" fn sceKernelDelaySysClockThread(
delay: *mut SceKernelSysClock,
) -> c_intDelay the current thread by a specified number of sysclocks
@param delay - Delay in sysclocks
@return 0 on success, < 0 on error