[][src]Function pspsdk_sys::sdk::sceKernelGetThreadmanIdList

pub unsafe extern "C" fn sceKernelGetThreadmanIdList(
    type_: SceKernelIdListType,
    readbuf: *mut SceUID,
    readbufsize: c_int,
    idcount: *mut c_int
) -> c_int

Get a list of UIDs from threadman. Allows you to enumerate resources such as threads or semaphores.

@param type - The type of resource to list, one of ::SceKernelIdListType. @param readbuf - A pointer to a buffer to store the list. @param readbufsize - The size of the buffer in SceUID units. @param idcount - Pointer to an integer in which to return the number of ids in the list.

@return < 0 on error. Either 0 or the same as idcount on success.