[−][src]Function pspsdk_sys::sdk::sceKernelLibcClock
pub unsafe extern "C" fn sceKernelLibcClock() -> clock_t
Get the processor clock used since the start of the process
pub unsafe extern "C" fn sceKernelLibcClock() -> clock_t
Get the processor clock used since the start of the process