sceKernelLoadModuleBuffer

Function sceKernelLoadModuleBuffer 

pub unsafe extern "C" fn sceKernelLoadModuleBuffer(
    buf: *mut c_void,
    bufsize: SceSize,
    flags: c_int,
    option: *mut SceKernelLMOption,
) -> SceUID
Load a module from a buffer

@param buf - Pointer to a buffer containing the module to load. The buffer must reside at an address that is a multiple to 64 bytes. @param bufsize - Size (in bytes) of the buffer pointed to by buf. @param flags - Unused, always 0. @param option - Pointer to an optional ::SceKernelLMOption structure.

@return The UID of the loaded module on success, otherwise one of ::PspKernelErrorCodes.