sceKernelLoadModuleBufferUsbWlan

Function sceKernelLoadModuleBufferUsbWlan 

pub unsafe extern "C" fn sceKernelLoadModuleBufferUsbWlan(
    bufsize: SceSize,
    buf: *mut c_void,
    flags: c_int,
    option: *mut SceKernelLMOption,
) -> SceUID
Load a module from a buffer using the USB/WLAN API.

Can only be called from kernel mode, or from a thread that has attributes of 0xa0000000.

@param bufsize - Size (in bytes) of the buffer pointed to by buf. @param buf - Pointer to a buffer containing the module to load. The buffer must reside at an address that is a multiple to 64 bytes. @param flags - Unused, always 0. @param option - Pointer to an optional ::SceKernelLMOption structure.

@return The UID of the loaded module on success, otherwise one of ::PspKernelErrorCodes.