[−][src]Function pspsdk_sys::sdk::sceKernelQueryModuleInfo
pub unsafe extern "C" fn sceKernelQueryModuleInfo(
modid: SceUID,
info: *mut SceKernelModuleInfo
) -> c_int
Query the information about a loaded module from its UID. @note This fails on v1.0 firmware (and even it worked has a limited structure) so if you want to be compatible with both 1.5 and 1.0 (and you are running in kernel mode) then call this function first then ::pspSdkQueryModuleInfoV1 if it fails, or make separate v1 and v1.5+ builds.
@param modid - The UID of the loaded module. @param info - Pointer to a ::SceKernelModuleInfo structure.
@return 0 on success, otherwise one of ::PspKernelErrorCodes.