[][src]Function pspsdk_sys::sdk::sceKernelReferThreadStatus

pub unsafe extern "C" fn sceKernelReferThreadStatus(
    thid: SceUID,
    info: *mut SceKernelThreadInfo
) -> c_int

Get the status information for the specified thread.

@param thid - Id of the thread to get status @param info - Pointer to the info structure to receive the data. Note: The structures size field should be set to sizeof(SceKernelThreadInfo) before calling this function.

@par Example: @code SceKernelThreadInfo status; status.size = sizeof(SceKernelThreadInfo); if(sceKernelReferThreadStatus(thid, &status) == 0) { Do something... } @endcode @return 0 if successful, otherwise the error code.