sceKernelSelfStopUnloadModule

Function sceKernelSelfStopUnloadModule 

pub unsafe extern "C" fn sceKernelSelfStopUnloadModule(
    unknown: c_int,
    argsize: SceSize,
    argp: *mut c_void,
) -> c_int
Stop and unload the current module.

@param unknown - Unknown (I’ve seen 1 passed). @param argsize - Size (in bytes) of the arguments that will be passed to module_stop(). @param argp - Pointer to arguments that will be passed to module_stop().

@return ??? on success, otherwise one of ::PspKernelErrorCodes.