[][src]Function pspsdk_sys::sdk::sceKernelVolatileMemLock

pub unsafe extern "C" fn sceKernelVolatileMemLock(
    unk: c_int,
    ptr: *mut *mut c_void,
    size: *mut c_int
) -> c_int

Allocate the extra 4megs of RAM

@param unk - No idea as it is never used, set to anything @param ptr - Pointer to a pointer to hold the address of the memory @param size - Pointer to an int which will hold the size of the memory

@return 0 on success