[][src]Function pspsdk_sys::sdk::sceKernelVolatileMemTryLock

pub unsafe extern "C" fn sceKernelVolatileMemTryLock(
    unk: c_int,
    ptr: *mut *mut c_void,
    size: *mut c_int
) -> c_int

Try and allocate the extra 4megs of RAM, will return an error if something has already allocated it

@param unk - No idea as it is never used, set to anything @param ptr - Pointer to a pointer to hold the address of the memory @param size - Pointer to an int which will hold the size of the memory

@return 0 on success