[−][src]Function pspsdk_sys::sdk::sceKernelcoreerr
pub unsafe extern "C" fn sceKernelcoreerr() -> SceUID
Function to get the current standard err file no
@return The coreerr fileno
pub unsafe extern "C" fn sceKernelcoreerr() -> SceUID
Function to get the current standard err file no
@return The coreerr fileno