[][src]Function pspsdk_sys::sdk::sceUtilityMsgDialogGetStatus

pub unsafe extern "C" fn sceUtilityMsgDialogGetStatus() -> c_int

Get the current status of a message dialog currently active.

@return 2 if the GUI is visible (you need to call sceUtilityMsgDialogGetStatus). 3 if the user cancelled the dialog, and you need to call sceUtilityMsgDialogShutdownStart. 4 if the dialog has been successfully shut down.