[][src]Struct pspsdk_sys::sdk::PspIoDrvFileArg

#[repr(C)]pub struct PspIoDrvFileArg {
    pub unk1: u32,
    pub fs_num: u32,
    pub drv: *mut PspIoDrvArg,
    pub unk2: u32,
    pub arg: *mut c_void,
}

Structure passed to the file functions of the io driver system

Fields

unk1: u32

Unknown

fs_num: u32

The file system number, e.g. if a file is opened as host5:/myfile.txt this field will be 5

drv: *mut PspIoDrvArg

Pointer to the driver structure

unk2: u32

Unknown, again

arg: *mut c_void

Pointer to a user defined argument, this is preserved on a per file basis