SceKernelSystemStatus

Struct SceKernelSystemStatus 

#[repr(C)]
pub struct SceKernelSystemStatus { pub size: SceSize, pub status: SceUInt, pub idleClocks: SceKernelSysClock, pub comesOutOfIdleCount: SceUInt, pub threadSwitchCount: SceUInt, pub vfpuSwitchCount: SceUInt, }
Structure to contain the system status returned by ::sceKernelReferSystemStatus

Fields

size: SceSize

Size of the structure (should be set prior to the call)

status: SceUInt

The status ?

idleClocks: SceKernelSysClock

The number of cpu clocks in the idle thread

comesOutOfIdleCount: SceUInt

Number of times we resumed from idle

threadSwitchCount: SceUInt

Number of thread context switches

vfpuSwitchCount: SceUInt

Number of vfpu switches ?