SceLibraryStubTable

Struct SceLibraryStubTable 

#[repr(C)]
pub struct SceLibraryStubTable { pub libname: *const c_char, pub version: [c_uchar; 2], pub attribute: c_ushort, pub len: c_uchar, pub vstubcount: c_uchar, pub stubcount: c_ushort, pub nidtable: *mut c_uint, pub stubtable: *mut c_void, pub vstubtable: *mut c_void, }
Specifies a library and a set of imports from that library. Use the len member to determine the real size of the table (size = len * 4).

Fields

libname: *const c_charversion: [c_uchar; 2]

Minimum required version of the library we want to import.

attribute: c_ushortlen: c_uchar

Length of this stub table in 32-bit WORDs.

vstubcount: c_uchar

The number of variables imported from the library.

stubcount: c_ushort

The number of functions imported from the library.

nidtable: *mut c_uint

Pointer to an array of NIDs.

stubtable: *mut c_void

Pointer to the imported function stubs.

vstubtable: *mut c_void

Pointer to the imported variable stubs.