[][src]Struct pspsdk_sys::sdk::UsbdDeviceReq

#[repr(C)]pub struct UsbdDeviceReq {
    pub endp: *mut UsbEndpoint,
    pub data: *mut c_void,
    pub size: c_int,
    pub unkc: c_int,
    pub func: *mut c_void,
    pub recvsize: c_int,
    pub retcode: c_int,
    pub unk1c: c_int,
    pub arg: *mut c_void,
    pub link: *mut c_void,
}

USB device request, used by ::sceUsbbdReqSend and ::sceUsbbdReqRecv.

Fields

endp: *mut UsbEndpoint

Pointer to the endpoint to queue request on

data: *mut c_void

Pointer to the data buffer to use in the request

size: c_int

Size of the data buffer (send == size of data, recv == size of max receive)

unkc: c_int

Unknown

func: *mut c_void

Pointer to the function to call on completion

recvsize: c_int

Resultant size (send == size of data sent, recv == size of data received)

retcode: c_int

Return code of the request, 0 == success, -3 == cancelled

unk1c: c_int

Unknown

arg: *mut c_void

A user specified pointer for the device request

link: *mut c_void

Link pointer to next request used by the driver, set it to NULL