[−][src]Type Definition pspsdk_sys::sdk::PspDebugRegBlock
type PspDebugRegBlock = _PspDebugRegBlock;
Structure to hold the register data associated with an exception
type PspDebugRegBlock = _PspDebugRegBlock;
Structure to hold the register data associated with an exception