pub unsafe extern "C" fn pspSdkInstallKernelLoadModulePatch() -> c_intExpand description
Patch sceLoadModuleWithApiType to remove the kernel check in loadmodule allowing all modules to load
@note This function must be called while running in kernel mode
@return 0 on success