pub unsafe extern "C" fn pspSdkQueryModuleInfoV1(
uid: SceUID,
modinfo: *mut SceKernelModuleInfo,
) -> c_intExpand description
Query a modules information from its uid. @note this is a replacement function for the broken kernel sceKernelQueryModuleInfo in v1.0 firmware DO NOT use on a anything above that version. This also needs kernel mode access where the normal one has a user mode stub.
@param uid - The UID of the module to query. @param modinfo - Pointer a module SceKernelModuleInfo structure.
@return < 0 on error.