[][src]Function pspsdk_sys::sdk::sceGeGetStack

pub unsafe extern "C" fn sceGeGetStack(
    stackId: c_int,
    stack: *mut PspGeStack
) -> c_int

Retrieve the stack of the display list currently being executed.

@param stackId - The ID of the stack to retrieve. @param stack - Pointer to a structure to store the stack, or NULL to not store it.

@return The number of stacks of the current display list, < 0 on error.