[−][src]Function pspsdk_sys::sdk::sceHttpSendRequest
pub unsafe extern "C" fn sceHttpSendRequest(
requestid: c_int,
data: *mut c_void,
datasize: c_uint
) -> c_int
Send a http request.
@param requestid - ID of the request created by sceHttpCreateRequest or sceHttpCreateRequestWithURL @param data - For POST methods specify a pointer to the post data, otherwise pass NULL @param datasize - For POST methods specify the size of the post data, otherwise pass 0 @return 0 on success, < 0 on error.