pub unsafe extern "C" fn sceKernelLoadModule(
path: *const c_char,
flags: c_int,
option: *mut SceKernelLMOption,
) -> SceUIDExpand description
Load a module. @note This function restricts where it can load from (such as from flash0) unless you call it in kernel mode. It also must be called from a thread.
@param path - The path to the module to load. @param flags - Unused, always 0 . @param option - Pointer to a mod_param_t structure. Can be NULL.
@return The UID of the loaded module on success, otherwise one of ::PspKernelErrorCodes.