pub unsafe extern "C" fn sceKernelLoadModuleMs(
path: *const c_char,
flags: c_int,
option: *mut SceKernelLMOption,
) -> SceUIDExpand description
Load a module from MS. @note This function restricts what it can load, e.g. it wont load plain executables.
@param path - The path to the module to load. @param flags - Unused, set to 0. @param option - Pointer to a mod_param_t structure. Can be NULL.
@return The UID of the loaded module on success, otherwise one of ::PspKernelErrorCodes.