[−][src]Function pspsdk_sys::sdk::sceKernelStopUnloadSelfModule
pub unsafe extern "C" fn sceKernelStopUnloadSelfModule(
argsize: SceSize,
argp: *mut c_void,
status: *mut c_int,
option: *mut SceKernelSMOption
) -> c_int
Stop and unload the current module.
@param argsize - Size (in bytes) of the arguments that will be passed to module_stop(). @param argp - Poitner to arguments that will be passed to module_stop(). @param status - Return value from module_stop(). @param option - Pointer to an optional ::SceKernelSMOption structure.
@return ??? on success, otherwise one of ::PspKernelErrorCodes.