[−][src]Function pspsdk_sys::sdk::sceKernelSysEventDispatch
pub unsafe extern "C" fn sceKernelSysEventDispatch(
ev_type_mask: c_int,
ev_id: c_int,
ev_name: *mut c_char,
param: *mut c_void,
result: *mut c_int,
break_nonzero: c_int,
break_handler: *mut PspSysEventHandler
) -> c_int
Dispatch a SysEvent event.
@param ev_type_mask - the event type mask @param ev_id - the event id @param ev_name - the event name @param param - the pointer to the custom parameters @param result - the pointer to the result @param break_nonzero - set to 1 to interrupt the calling chain after the first non-zero return @param break_handler - the pointer to the event handler having interrupted @return 0 on success, < 0 on error