[−][src]Struct pspsdk_sys::sdk::PspIoDrvFileArg
Structure passed to the file functions of the io driver system
Fields
unk1: u32Unknown
fs_num: u32The file system number, e.g. if a file is opened as host5:/myfile.txt this field will be 5
drv: *mut PspIoDrvArgPointer to the driver structure
unk2: u32Unknown, again
arg: *mut c_voidPointer to a user defined argument, this is preserved on a per file basis