#[repr(C)]pub struct SceKernelSystemStatus {
pub size: SceSize,
pub status: SceUInt,
pub idleClocks: SceKernelSysClock,
pub comesOutOfIdleCount: SceUInt,
pub threadSwitchCount: SceUInt,
pub vfpuSwitchCount: SceUInt,
}Expand description
Structure to contain the system status returned by ::sceKernelReferSystemStatus
Fields
size: SceSizeSize of the structure (should be set prior to the call)
status: SceUIntThe status ?
idleClocks: SceKernelSysClockThe number of cpu clocks in the idle thread
comesOutOfIdleCount: SceUIntNumber of times we resumed from idle
threadSwitchCount: SceUIntNumber of thread context switches
vfpuSwitchCount: SceUIntNumber of vfpu switches ?