#[repr(C)]pub struct SceLibraryEntryTable {
pub libname: *const c_char,
pub version: [c_uchar; 2],
pub attribute: c_ushort,
pub len: c_uchar,
pub vstubcount: c_uchar,
pub stubcount: c_ushort,
pub entrytable: *mut c_void,
}Expand description
Defines a library and its exported functions and variables. Use the len member to determine the real size of the table (size = len * 4).
Fields
libname: *const c_charThe library’s name.
version: [c_uchar; 2]Library version.
attribute: c_ushortLibrary attributes.
len: c_ucharLength of this entry table in 32-bit WORDs.
vstubcount: c_ucharThe number of variables exported by the library.
stubcount: c_ushortThe number of functions exported by the library.
entrytable: *mut c_voidPointer to the entry table; an array of NIDs followed by pointers to functions and variables.