[][src]Struct pspsdk_sys::sdk::SceLibraryEntryTable

#[repr(C)]pub struct SceLibraryEntryTable {
    pub libname: *const c_char,
    pub version: [c_uchar; 2],
    pub attribute: c_ushort,
    pub len: c_uchar,
    pub vstubcount: c_uchar,
    pub stubcount: c_ushort,
    pub entrytable: *mut c_void,
}

Defines a library and its exported functions and variables. Use the len member to determine the real size of the table (size = len * 4).

Fields

libname: *const c_char

The library's name.

version: [c_uchar; 2]

Library version.

attribute: c_ushort

Library attributes.

len: c_uchar

Length of this entry table in 32-bit WORDs.

vstubcount: c_uchar

The number of variables exported by the library.

stubcount: c_ushort

The number of functions exported by the library.

entrytable: *mut c_void

Pointer to the entry table; an array of NIDs followed by pointers to functions and variables.