#[repr(C)]pub struct SceLibraryStubTable {
pub libname: *const c_char,
pub version: [c_uchar; 2],
pub attribute: c_ushort,
pub len: c_uchar,
pub vstubcount: c_uchar,
pub stubcount: c_ushort,
pub nidtable: *mut c_uint,
pub stubtable: *mut c_void,
pub vstubtable: *mut c_void,
}Expand description
Specifies a library and a set of imports from that library. Use the len member to determine the real size of the table (size = len * 4).
Fields
libname: *const c_charversion: [c_uchar; 2]Minimum required version of the library we want to import.
attribute: c_ushortlen: c_ucharLength of this stub table in 32-bit WORDs.
vstubcount: c_ucharThe number of variables imported from the library.
stubcount: c_ushortThe number of functions imported from the library.
nidtable: *mut c_uintPointer to an array of NIDs.
stubtable: *mut c_voidPointer to the imported function stubs.
vstubtable: *mut c_voidPointer to the imported variable stubs.