[−][src]Struct pspsdk_sys::sdk::UsbdDeviceReq
USB device request, used by ::sceUsbbdReqSend and ::sceUsbbdReqRecv.
Fields
endp: *mut UsbEndpointPointer to the endpoint to queue request on
data: *mut c_voidPointer to the data buffer to use in the request
size: c_intSize of the data buffer (send == size of data, recv == size of max receive)
unkc: c_intUnknown
func: *mut c_voidPointer to the function to call on completion
recvsize: c_intResultant size (send == size of data sent, recv == size of data received)
retcode: c_intReturn code of the request, 0 == success, -3 == cancelled
unk1c: c_intUnknown
arg: *mut c_voidA user specified pointer for the device request
link: *mut c_voidLink pointer to next request used by the driver, set it to NULL